/*
 * ChangeCase.cpp 
 *
 * (c) Copyright 1999 Kjell V. Normann
 * Freeware
 *
 * FUNCTION:
 * 	BeIDE add-on that converts the selected text
 * 	to uppercase or lowercase depending on whether
 * 	SHIFT is pressed
 *
 */

#include <stdio.h>
#include <ctype.h>
#include "MTextAddOn.h"


extern "C" {
__declspec(dllexport) status_t perform_edit(MTextAddOn *addon);
}

long perform_edit(MTextAddOn *addon)
{
	long	startsel, endsel;
	char	*text, *txt_start, *txt_end;
	char	*tempbuf, *buf;
	bool	lower = false;

	/*
	 * If the SHIFT key is pressed, we should convert to
	 * lowercase
	 */

	if((modifiers() & B_SHIFT_KEY) != 0)
		lower = true;

	/* Get selected text positions */

	addon->GetSelection(&startsel, &endsel);
	
	if(endsel <= startsel)
		return B_ERROR;
		
	/* Get pointer to text */

	text = (char *) addon->Text();
	txt_start = text + startsel;
	txt_end = text + endsel;
	
	/* Allocate temporary buffer for the text */

	if((tempbuf = buf = (char *) malloc(txt_end - txt_start + 1)) == NULL)
		return B_ERROR;

	/* Perform the conversion (from selected text to buffer */

	for(; txt_start < txt_end ; txt_start++)
		*buf++ = lower ? tolower(*txt_start) : toupper(*txt_start);
	*buf = '\0';

	/* Delete selected text in editor */

	addon->Delete();

	/* Insert converted text into editor */

	addon->Insert(tempbuf);

	free(tempbuf);

	return B_NO_ERROR;
}
